Structs
- GetChat
History Request - GetChat
History Request Builder - Use builder syntax to set the inputs and finish with
build(). - Push
Chat Message Request - Push
Chat Message Request Builder - Use builder syntax to set the inputs and finish with
build().