Module capital

Module capital 

Structs

CheatGetInfluenceRequest
CheatGetInfluenceRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetInfluenceRequest
CheatSetInfluenceRequestBuilder
Use builder syntax to set the inputs and finish with build().