Module city

Module city 

Structs

CheatFillWorldRequest
CheatFillWorldRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetCitiesRequest
CheatGetCitiesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetCityRequest
CheatGetCityRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetStabilityRequest
CheatSetStabilityRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSpawnCityRequest
CheatSpawnCityRequestBuilder
Use builder syntax to set the inputs and finish with build().