Module infrastructure

Module infrastructure 

Structs

CheatGetAcademyRecruitQueueRequest
CheatGetAcademyRecruitQueueRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetAcademyRecruitQueuesRequest
CheatGetAcademyRecruitQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetAllAcademyRecruitQueuesRequest
CheatGetAllAcademyRecruitQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetAllPrefectureBuildQueuesRequest
CheatGetAllPrefectureBuildQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetAllStableRecruitQueuesRequest
CheatGetAllStableRecruitQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetInfrastructureRequest
CheatGetInfrastructureRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetPrefectureBuildQueueRequest
CheatGetPrefectureBuildQueueRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetPrefectureBuildQueuesRequest
CheatGetPrefectureBuildQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetStableRecruitQueueRequest
CheatGetStableRecruitQueueRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetStableRecruitQueuesRequest
CheatGetStableRecruitQueuesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetStorageCapacityRequest
CheatGetStorageCapacityRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetBuildingLevelRequest
CheatSetBuildingLevelRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxInfrastructureRequest
CheatSetMaxInfrastructureRequestBuilder
Use builder syntax to set the inputs and finish with build().