Module military

Module military 

Structs

CheatGetIdleArmiesAtRequest
CheatGetIdleArmiesAtRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetIdlePersonnelAtRequest
CheatGetIdlePersonnelAtRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetManeuversOfRequest
CheatGetManeuversOfRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatGetManeuversRequest
CheatGetManeuversRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSpawnPersonnelRequest
CheatSpawnPersonnelRequestBuilder
Use builder syntax to set the inputs and finish with build().