Module npc

Module npc 

Structs

CheatGetEthicsRequest
CheatGetEthicsRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetBotEthicsRequest
CheatSetBotEthicsRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSpawnBotRequest
CheatSpawnBotRequestBuilder
Use builder syntax to set the inputs and finish with build().