Module resources

Module resources 

Structs

CheatGetResourcesRequest
CheatGetResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetFoodRequest
CheatSetFoodRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetIronRequest
CheatSetIronRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxFoodRequest
CheatSetMaxFoodRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxIronRequest
CheatSetMaxIronRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxResourcesRequest
CheatSetMaxResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxSiloResourcesRequest
CheatSetMaxSiloResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxStoneRequest
CheatSetMaxStoneRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxWarehouseResourcesRequest
CheatSetMaxWarehouseResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetMaxWoodRequest
CheatSetMaxWoodRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetResourcesRequest
CheatSetResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetStoneRequest
CheatSetStoneRequestBuilder
Use builder syntax to set the inputs and finish with build().
CheatSetWoodRequest
CheatSetWoodRequestBuilder
Use builder syntax to set the inputs and finish with build().