Module city

Module city 

Structs

GetCitiesRequest
GetCitiesRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetCityRequest
GetCityRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetCityScoreRequest
GetCityScoreRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicCitiesRequest
GetPublicCitiesRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicCityRequest
GetPublicCityRequestBuilder
Use builder syntax to set the inputs and finish with build().
RenameCityRequest
RenameCityRequestBuilder
Use builder syntax to set the inputs and finish with build().
SearchCityRequest
SearchCityRequestBuilder
Use builder syntax to set the inputs and finish with build().
SearchPublicCityRequest
SearchPublicCityRequestBuilder
Use builder syntax to set the inputs and finish with build().