Module bot

Module bot 

Structs

GetBotCoordsRequest
GetBotCoordsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicBotRequest
GetPublicBotRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicBotsRequest
GetPublicBotsRequestBuilder
Use builder syntax to set the inputs and finish with build().