Structs
- GetPrecursor
Coords Request - GetPrecursor
Coords Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Precursor Request - GetPublic
Precursor Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Precursors Request - GetPublic
Precursors Request Builder - Use builder syntax to set the inputs and finish with
build().