Module player

Module player 

Structs

GetPlayerCoordsRequest
GetPlayerCoordsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerIdsRequest
GetPlayerIdsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerMaintenanceRequest
GetPlayerMaintenanceRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerMilitaryRequest
GetPlayerMilitaryRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerReportsRequest
GetPlayerReportsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerRequest
GetPlayerRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerStatusRequest
GetPlayerStatusRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerStorageCapacityRequest
GetPlayerStorageCapacityRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPlayerWorldsRequest
GetPlayerWorldsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicPlayerRequest
GetPublicPlayerRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetPublicPlayersRequest
GetPublicPlayersRequestBuilder
Use builder syntax to set the inputs and finish with build().
PlayerExistsRequest
PlayerExistsRequestBuilder
Use builder syntax to set the inputs and finish with build().
SetPlayerStatusRequest
SetPlayerStatusRequestBuilder
Use builder syntax to set the inputs and finish with build().
SpawnPlayerRequest
SpawnPlayerRequestBuilder
Use builder syntax to set the inputs and finish with build().