Module report

Module report 

Structs

ForwardReportRequest
ForwardReportRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetReportRequest
GetReportRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetReportsRequest
GetReportsRequestBuilder
Use builder syntax to set the inputs and finish with build().
RemoveReportRequest
RemoveReportRequestBuilder
Use builder syntax to set the inputs and finish with build().