Module round

Module round 

Structs

GetRoundRequest
GetRoundRequestBuilder
Use builder syntax to set the inputs and finish with build().
SetPlayerReadyRequest
SetPlayerReadyRequestBuilder
Use builder syntax to set the inputs and finish with build().
StartRoundRequest
StartRoundRequestBuilder
Use builder syntax to set the inputs and finish with build().