Structs
- Create
User Request - Create
User Request Builder - Use builder syntax to set the inputs and finish with
build(). - User
Exists Request - User
Exists Request Builder - Use builder syntax to set the inputs and finish with
build().
build().build().