Structs
- Create
Remote World Request - Create
Remote World Request Builder - Use builder syntax to set the inputs and finish with
build(). - Delete
Remote World Request - Delete
Remote World Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetRemote
World Request - GetRemote
World Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Bots Request - GetWorld
Bots Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Config Request - GetWorld
Config Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Personnel Request - GetWorld
Personnel Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Players Request - GetWorld
Players Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Precursors Request - GetWorld
Precursors Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetWorld
Stats Request - GetWorld
Stats Request Builder - Use builder syntax to set the inputs and finish with
build(). - Leave
Request - Leave
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Save
Local World Request - Save
Local World Request Builder - Use builder syntax to set the inputs and finish with
build().