pub struct CheatGetInfrastructureResponse(pub Infrastructure);Tuple Fields
0: InfrastructureMethods from Deref<Target = Infrastructure>
pub fn storage(&self, id: StorageId) -> &dyn Storage
pub fn mine(&self, id: MineId) -> &dyn Mine
pub fn score(&self, stats: &InfrastructureStats) -> Result<Score, Error>
Sourcepub fn round_base_production(
&self,
stats: &InfrastructureStats,
) -> Result<Resources, Error>
pub fn round_base_production( &self, stats: &InfrastructureStats, ) -> Result<Resources, Error>
Determines the amount of resources generated by the mines at their current level, before applying any modifiers, such as city stability.
pub fn academy(&self) -> &Academy
pub fn farm(&self) -> &Farm
pub fn iron_mine(&self) -> &IronMine
pub fn prefecture(&self) -> &Prefecture
pub fn quarry(&self) -> &Quarry
pub fn sawmill(&self) -> &Sawmill
pub fn silo(&self) -> &Silo
pub fn stable(&self) -> &Stable
pub fn wall(&self) -> &Wall
pub fn warehouse(&self) -> &Warehouse
pub fn workshop(&self) -> &Workshop
pub fn building(&self, id: BuildingId) -> &dyn Building
Sourcepub fn base_maintenance(
&self,
stats: &InfrastructureStats,
) -> Result<Maintenance, Error>
pub fn base_maintenance( &self, stats: &InfrastructureStats, ) -> Result<Maintenance, Error>
Determines the maintenance tax required for all buildings at their current levels.
Sourcepub fn has_required_levels(
&self,
requirements: &InfrastructureRequirements,
) -> bool
pub fn has_required_levels( &self, requirements: &InfrastructureRequirements, ) -> bool
Determines whether the infrastructure meets the requirements.