pub struct GetPlayerMilitaryResponse(pub Military);Tuple Fields
0: MilitaryMethods from Deref<Target = Military>
pub fn collapse_armies(&mut self)
pub fn collapse_armies_in<K>(&mut self, key: K)where
K: ContinentKey,
Sourcepub fn intersection<K, I>(&self, keys: I) -> Result<Military, Error>where
K: ContinentKey,
I: IntoIterator<Item = K>,
pub fn intersection<K, I>(&self, keys: I) -> Result<Military, Error>where
K: ContinentKey,
I: IntoIterator<Item = K>,
Creates a new instance containing only entries related to a given set of coords.
pub fn army(&self, id: ArmyId) -> Result<&Army, Error>
pub fn armies(&self) -> impl Iterator<Item = &Army>
pub fn count_armies(&self) -> usize
pub fn armies_at<K>(&self, key: K) -> &[Army]where
K: ContinentKey,
pub fn count_armies_at<K>(&self, key: K) -> usizewhere
K: ContinentKey,
pub fn idle_armies_at<K>(&self, key: K) -> impl Iterator<Item = &Army>where
K: ContinentKey,
pub fn armies_of<R>(&self, owner: R) -> impl Iterator<Item = &Army>
pub fn personnel(&self, id: ArmyId) -> Result<&ArmyPersonnel, Error>
pub fn personnel_of<R>(&self, owner: R) -> impl Iterator<Item = &ArmyPersonnel>
pub fn fold_personnel_of<R>(&self, owner: R) -> ArmyPersonnel
pub fn idle_personnel_at<K>(
&self,
key: K,
) -> impl Iterator<Item = &ArmyPersonnel>where
K: ContinentKey,
pub fn fold_idle_personnel_at<K>(&self, key: K) -> ArmyPersonnelwhere
K: ContinentKey,
pub fn squads(&self, id: ArmyId) -> Result<Vec<Squad>, Error>
pub fn idle_squads_at<K>(&self, key: K) -> Vec<Squad>where
K: ContinentKey,
pub fn maneuver(&self, id: ManeuverId) -> Result<&Maneuver, Error>
pub fn maneuvers(&self) -> impl Iterator<Item = &Maneuver>
Sourcepub fn maneuvers_at(&self, coord: Coord) -> impl Iterator<Item = &Maneuver>
pub fn maneuvers_at(&self, coord: Coord) -> impl Iterator<Item = &Maneuver>
Find all maneuvers whose origin or destination matches the specified coord.
pub fn score_of<R>(&self, owner: R) -> Score
pub fn maintenance_of<R>(&self, owner: R) -> Maintenance
pub fn power_of<R>(&self, owner: R) -> Power
pub fn attack_of<R>(&self, owner: R) -> AttackPower
pub fn defense_of<R>(&self, owner: R) -> DefensePower