Structs
- Cheat
GetInfluence Request - Cheat
GetInfluence Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetInfluence Request - Cheat
SetInfluence Request Builder - Use builder syntax to set the inputs and finish with
build().