Structs
- Cheat
Fill World Request - Cheat
Fill World Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetCities Request - Cheat
GetCities Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetCity Request - Cheat
GetCity Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetStability Request - Cheat
SetStability Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
Spawn City Request - Cheat
Spawn City Request Builder - Use builder syntax to set the inputs and finish with
build().