Structs
- Cheat
GetAcademy Recruit Queue Request - Cheat
GetAcademy Recruit Queue Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetAcademy Recruit Queues Request - Cheat
GetAcademy Recruit Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetAll Academy Recruit Queues Request - Cheat
GetAll Academy Recruit Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetAll Prefecture Build Queues Request - Cheat
GetAll Prefecture Build Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetAll Stable Recruit Queues Request - Cheat
GetAll Stable Recruit Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetInfrastructure Request - Cheat
GetInfrastructure Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetPrefecture Build Queue Request - Cheat
GetPrefecture Build Queue Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetPrefecture Build Queues Request - Cheat
GetPrefecture Build Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetStable Recruit Queue Request - Cheat
GetStable Recruit Queue Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetStable Recruit Queues Request - Cheat
GetStable Recruit Queues Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetStorage Capacity Request - Cheat
GetStorage Capacity Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetBuilding Level Request - Cheat
SetBuilding Level Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Infrastructure Request - Cheat
SetMax Infrastructure Request Builder - Use builder syntax to set the inputs and finish with
build().