Structs
- Cheat
GetIdle Armies AtRequest - Cheat
GetIdle Armies AtRequest Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetIdle Personnel AtRequest - Cheat
GetIdle Personnel AtRequest Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetManeuvers OfRequest - Cheat
GetManeuvers OfRequest Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
GetManeuvers Request - Cheat
GetManeuvers Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
Spawn Personnel Request - Cheat
Spawn Personnel Request Builder - Use builder syntax to set the inputs and finish with
build().