Structs
- Cheat
GetResources Request - Cheat
GetResources Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetFood Request - Cheat
SetFood Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetIron Request - Cheat
SetIron Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Food Request - Cheat
SetMax Food Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Iron Request - Cheat
SetMax Iron Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Resources Request - Cheat
SetMax Resources Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Silo Resources Request - Cheat
SetMax Silo Resources Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Stone Request - Cheat
SetMax Stone Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Warehouse Resources Request - Cheat
SetMax Warehouse Resources Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetMax Wood Request - Cheat
SetMax Wood Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetResources Request - Cheat
SetResources Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetStone Request - Cheat
SetStone Request Builder - Use builder syntax to set the inputs and finish with
build(). - Cheat
SetWood Request - Cheat
SetWood Request Builder - Use builder syntax to set the inputs and finish with
build().