Structs
- GetCities
Request - GetCities
Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetCity
Request - GetCity
Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetCity
Score Request - GetCity
Score Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Cities Request - GetPublic
Cities Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
City Request - GetPublic
City Request Builder - Use builder syntax to set the inputs and finish with
build(). - Rename
City Request - Rename
City Request Builder - Use builder syntax to set the inputs and finish with
build(). - Search
City Request - Search
City Request Builder - Use builder syntax to set the inputs and finish with
build(). - Search
Public City Request - Search
Public City Request Builder - Use builder syntax to set the inputs and finish with
build().