Module market

Module market 

Structs

GetMarketFeeRequest
GetMarketFeeRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetMarketRequest
GetMarketRequestBuilder
Use builder syntax to set the inputs and finish with build().
SendResourcesRequest
SendResourcesRequestBuilder
Use builder syntax to set the inputs and finish with build().