Structs
- GetMarket
FeeRequest - GetMarket
FeeRequest Builder - Use builder syntax to set the inputs and finish with
build(). - GetMarket
Request - GetMarket
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Send
Resources Request - Send
Resources Request Builder - Use builder syntax to set the inputs and finish with
build().