Structs
- GetBot
Coords Request - GetBot
Coords Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
BotRequest - GetPublic
BotRequest Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Bots Request - GetPublic
Bots Request Builder - Use builder syntax to set the inputs and finish with
build().