Structs
- GetPlayer
Coords Request - GetPlayer
Coords Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
IdsRequest - GetPlayer
IdsRequest Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Maintenance Request - GetPlayer
Maintenance Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Military Request - GetPlayer
Military Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Reports Request - GetPlayer
Reports Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Request - GetPlayer
Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Status Request - GetPlayer
Status Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Storage Capacity Request - GetPlayer
Storage Capacity Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPlayer
Worlds Request - GetPlayer
Worlds Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Player Request - GetPublic
Player Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetPublic
Players Request - GetPublic
Players Request Builder - Use builder syntax to set the inputs and finish with
build(). - Player
Exists Request - Player
Exists Request Builder - Use builder syntax to set the inputs and finish with
build(). - SetPlayer
Status Request - SetPlayer
Status Request Builder - Use builder syntax to set the inputs and finish with
build(). - Spawn
Player Request - Spawn
Player Request Builder - Use builder syntax to set the inputs and finish with
build().