Module ranking

Module ranking 

Structs

GetRankRequest
GetRankRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetRankingRequest
GetRankingRequestBuilder
Use builder syntax to set the inputs and finish with build().