Structs
- Forward
Report Request - Forward
Report Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetReport
Request - GetReport
Request Builder - Use builder syntax to set the inputs and finish with
build(). - GetReports
Request - GetReports
Request Builder - Use builder syntax to set the inputs and finish with
build(). - Remove
Report Request - Remove
Report Request Builder - Use builder syntax to set the inputs and finish with
build().