Structs
- GetRound
Request - GetRound
Request Builder - Use builder syntax to set the inputs and finish with
build(). - SetPlayer
Ready Request - SetPlayer
Ready Request Builder - Use builder syntax to set the inputs and finish with
build(). - Start
Round Request - Start
Round Request Builder - Use builder syntax to set the inputs and finish with
build().