Module world

Module world 

Structs

CreateRemoteWorldRequest
CreateRemoteWorldRequestBuilder
Use builder syntax to set the inputs and finish with build().
DeleteRemoteWorldRequest
DeleteRemoteWorldRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetRemoteWorldRequest
GetRemoteWorldRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldBotsRequest
GetWorldBotsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldConfigRequest
GetWorldConfigRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldPersonnelRequest
GetWorldPersonnelRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldPlayersRequest
GetWorldPlayersRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldPrecursorsRequest
GetWorldPrecursorsRequestBuilder
Use builder syntax to set the inputs and finish with build().
GetWorldStatsRequest
GetWorldStatsRequestBuilder
Use builder syntax to set the inputs and finish with build().
LeaveRequest
LeaveRequestBuilder
Use builder syntax to set the inputs and finish with build().
SaveLocalWorldRequest
SaveLocalWorldRequestBuilder
Use builder syntax to set the inputs and finish with build().